##########################################################
###### STARD data, QIDS-C 16 symptoms, weeks 0 & 6 #######
##########################################################

library(qgraph)
library(ggplot2)
library(pcaPA)
library(psych)

setwd("C:/Users/u0097060/Dropbox/Research/My Papers/1. First author publications/MI paper/analyses/R")

data<-read.csv("qids.csv", head=T)
data[data == -999] <- NA

##### SELECT QIDS SYMPTOMS FOR t0, t6 

data <- subset(data,select=c(sex,age,qids.0n,qids.6n,date.01,date.67,
                              s1.0n,s1.6n,
                              s2.0n,s2.6n,
                              s3.0n,s3.6n,
                              s4.0n,s4.6n,
                              s5.0n,s5.6n,
                              s67.0n,s67.6n,
                              s89.0n,s89.6n,
                              s10.0n,s10.6n,
                              s11.0n,s11.6n,
                              s12.0n,s12.6n,
                              s13.0n,s13.6n,
                              s14.0n,s14.6n,
                              s15.0n,s15.6n,
                              s16.0n,s16.6n)) 

s.q=c("Q01","Q02","Q03","Q04","Q05", "Q06","Q07","Q08","Q09","Q10", "Q11","Q12", "Q13","Q14")

data <- na.omit(data) # n=1938


##### DESCRIPTIVE STATISTICS
mean(data$age) # 41.5
sd(data$age) # 13.11
mean(data$sex) # 1.61
mean(data$date.01/7) # 0.00
sd(data$date.01/7) #  0.00
mean(data$date.67/7) # 6.18
sd(data$date.67/7) #  0.39

mean(data$qids.0n) # 16.27
sd(data$qids.0n) #  3.36
mean(data$qids.6n) # 9.53
sd(data$qids.6n) #  4.87

### mean sd of all symptoms at baseline. t0=.89; t6=.87
(sd(data$s1.0n)+sd(data$s2.0n)+sd(data$s3.0n)+sd(data$s4.0n)+sd(data$s5.0n)+sd(data$s67.0n)+sd(data$s89.0n)+
  sd(data$s10.0n)+sd(data$s11.0n)+sd(data$s12.0n)+sd(data$s13.0n)+sd(data$s14.0n)+sd(data$s15.0n)+sd(data$s16.0n))/14 
(sd(data$s1.6n)+   sd(data$s2.6n)+   sd(data$s3.6n)+   sd(data$s4.6n)+   sd(data$s5.6n)+   sd(data$s67.6n)+   sd(data$s89.6n)+   sd(data$s10.6n)+
   sd(data$s11.6n)+   sd(data$s12.6n)+   sd(data$s13.6n)+   sd(data$s14.6n)+   sd(data$s15.6n)+   sd(data$s16.6n))/14 

### significant increase in sum score from 0 to 6?
t.test(data$qids.0n, data$qids.6n, paired=T) #t = 62.97, df = 1937, p < 2.2e-16


### sum score histograms
qids.0n=as.data.frame(data$qids.0n)
qids.6n=as.data.frame(data$qids.6n)
names(qids.0n)[names(qids.0n)=="data$qids.0n"] <- "length"
names(qids.6n)[names(qids.6n)=="data$qids.6n"] <- "length"
qids.0n$time <- 'baseline'
qids.6n$time <- 'week 6'
q.plot <- rbind(qids.0n, qids.6n)

# pdf("Q_density.pdf")
# ggplot(q.plot, aes(length, fill = time)) + geom_density(alpha = 0.2)+ theme_bw() +
#   xlab("QIDS-16") + ylab("Density") 
# dev.off()


##### CONSTRUCT MATRICES FOR EACH TIMEPOINT
t0<- subset(data,select=c(s1.0n, s2.0n, s3.0n, s4.0n, s5.0n, s67.0n, 
                           s89.0n, s10.0n, s11.0n, s12.0n, s13.0n, s14.0n, s15.0n, s16.0n))
t6<- subset(data,select=c(s1.6n, s2.6n, s3.6n, s4.6n, s5.6n, s67.6n, 
                           s89.6n, s10.6n, s11.6n, s12.6n, s13.6n, s14.6n, s15.6n, s16.6n))
t6[, c(1:14)] <- sapply(t6[, c(1:14)], as.numeric)




##### PARALLEL ANALYSIS
### Eigenvalues Scree plots
t0.Q <- cor_auto(t0)
t6.Q <- cor_auto(t6)

### Conduct parallel analysis
PA.t0.Q = fa.parallel.poly(t0, fm="wls", global=F) #4 factors > PA results
PA.t6.Q = fa.parallel.poly(t6, fm="wls", global=F) #3 factors > PA results
# t0 and t6 PA results nearly identical, so we use t0 for the plot

eigen.Q <- rbind(
  data.frame(
    t = 0,
    x = 1:ncol(t0.Q),
    eigen = eigen(t0.Q)$values
  ),
  
    data.frame(
    t = 6,
    x = 1:ncol(t6.Q),
    eigen = eigen(t6.Q)$values
  )
) #these eigenvalues are identical to WLSMV mplus eigenvalues derived from EFA

### Plot EV
eigen.Q2=eigen.Q
t <- c("PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA")
x <- 1:14
# R psych ordinal P results: enter them into bracket manually
eigen <- c(1.18,1.14,1.11,1.08,1.06,1.04,1.02,1.01,0,0,0,0,0,0)
df.q <- data.frame(t,x,eigen)
eigen.Q2 <- rbind(eigen.Q2, df.q)

g.Q2color <- ggplot(eigen.Q2, aes(x = x, y = eigen, colour = factor(t))) + 
  geom_line() + 
  geom_point(size = 3) + 
  theme_bw() + theme(legend.title=element_blank()) +
  scale_x_continuous(limits = c(1, 7), breaks = 1:7) +
  scale_y_continuous(limits = c(0, 8), breaks = c(0:8)) +
  xlab("Factors") +
  ylab("Eigenvalues") + 
  ggtitle("QIDS-C Eigenvalues at weeks 0 and 6")

g.Q2bw <- ggplot(eigen.Q2, aes(x = x, y = eigen, shape = t)) + 
  geom_line() + 
  geom_point(size = 3) + 
  theme_bw() + theme(legend.title=element_blank()) +
  scale_x_continuous(limits = c(1, 7), breaks = 1:7) +
  scale_y_continuous(limits = c(0, 8), breaks = c(0:8)) +
  xlab("Factors") +
  ylab("Eigenvalues") + 
  ggtitle("QIDS-C Eigenvalues at weeks 0 and 6")

ggsave(plot=g.Q2color,height=5,width=7, filename="eigenvalues_QIDS_color.pdf", useDingbats=FALSE)
ggsave(plot=g.Q2bw,height=5,width=7, filename="eigenvalues_QIDS_bw.pdf", useDingbats=FALSE)


##### INTERCORRELATION & ALPHA

### matrix sum without diagonal
mean(t0.Q[upper.tri(t0.Q)])
mean(t6.Q[upper.tri(t6.Q)])

### alpha
library(psych)
alpha(t0.Q)
alpha(t6.Q)







